<img width="128" height="128" src="https://raw.githubusercontent.com/victoriyaforsythe/PyIRTAM/main/docs/figures/PyIRTAM_logo.png" alt="Black circle with PyIRTAM logo of two snakes marking the data-influenced EIA" title="PyIRTAM Logo" style="float:left;">

# PyIRTAM

[![PyPI Package latest release](https://img.shields.io/pypi/v/PyIRTAM.svg)](https://pypi.org/project/PyIRTAM/)
[![Build Status](https://github.com/victoriyaforsythe/PyIRTAM/actions/workflows/main.yml/badge.svg)](https://github.com/victoriyaforsythe/PyIRTAM/actions/workflows/main.yml)
[![Coverage Status](https://coveralls.io/repos/github/victoriyaforsythe/PyIRTAM/badge.svg?branch=main)](https://coveralls.io/github/victoriyaforsythe/PyIRTAM?branch=main)
[![Documentation Status](https://readthedocs.org/projects/pyirtam/badge/?version=latest)](https://pyirtam.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.10844521.svg)](https://doi.org/10.5281/zenodo.10844521)

Python tool for processing IRTAM coefficients that evaluates ionospheric
parameters and electron density on the entire given global grid and for the
entire day simultaneously.

## Documentation

PyIRTAM documentation can be found [here](https://pyirtam.readthedocs.io/en/latest/index.html)

## Getting Started

`pip install pyirtam`

Or read the [installation guide](https://pyirtam.readthedocs.io/en/latest/installation.html)

## Examples of how to use PyIRTAM

Tutorials are available [examples](https://pyirtam.readthedocs.io/en/latest/examples.html)

## Jupyter tutorial

Tutorials with Jupyter are available [tutorials](https://github.com/victoriyaforsythe/PyIRTAM/tree/main/docs/tutorials)
